@@ -64,7 +64,7 @@ apply_settings (GpsDataLoggerWidget * self)
     gint my_interval;
 
     if (self->settings->method_agnss)
-        my_method = my_method | LOCATION_METHOD_AGNSS;
+	    my_method = my_method | LOCATION_METHOD_AGNSS;
     if (self->settings->method_gnss)
         my_method = my_method | LOCATION_METHOD_GNSS;
     if (self->settings->method_acwp)
@@ -72,7 +72,7 @@ apply_settings (GpsDataLoggerWidget * self)
     if (self->settings->method_cwp)
         my_method = my_method | LOCATION_METHOD_CWP;
     if (self->settings->interval == 0)
-        my_interval = LOCATION_INTERVAL_1S;
+	    my_interval = LOCATION_INTERVAL_1S;
     else if (self->settings->interval == 1)
         my_interval = LOCATION_INTERVAL_2S;
     else if (self->settings->interval == 2)
@@ -613,7 +613,7 @@ update_status_and_buttons (GpsDataLoggerWidget * self)
 {
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- enter (state: %d)\n"), __func__, self->app_state);
+        g_fprintf(self->logfile, "%s -- enter (state: %d)\n", __func__, self->app_state);
 	fflush(self->logfile);
     }
 #endif
@@ -626,7 +626,7 @@ update_status_and_buttons (GpsDataLoggerWidget * self)
 		self->rec_button_enabled = FALSE;
 		self->stop_button_enabled = TRUE;
 #ifndef __arm__
-		g_print(_(" starting: loading new icon, disabling rec\n"));
+		g_print(" starting: loading new icon, disabling rec\n");
 #endif
 		break;
 	case APP_STATE_RECORDING:
@@ -662,14 +662,14 @@ update_status_and_buttons (GpsDataLoggerWidget * self)
 		self->rec_button_enabled = TRUE;
 		self->stop_button_enabled = FALSE;
 #ifndef __arm__
-		g_print(_(" idle or default\n"));
+		g_print(" idle or default\n");
 #endif
 		break;
     }
     gtk_widget_queue_draw(GTK_WIDGET(self));
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- leave\n"), __func__);
+        g_fprintf(self->logfile, "%s -- leave\n", __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -682,7 +682,7 @@ handle_button_press (GtkWidget *button,
     GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (data);
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- enter (state: %d)\n"), __func__, self->app_state);
+        g_fprintf(self->logfile, "%s -- enter (state: %d)\n", __func__, self->app_state);
 	fflush(self->logfile);
     }
 #endif
@@ -691,15 +691,15 @@ handle_button_press (GtkWidget *button,
         if (self->app_state == APP_STATE_IDLE) {
             self->app_state = APP_STATE_STARTING;
 #ifndef __arm__
-	    g_print(_(" new state: starting\n"));
-            g_print(_("handle_button_press : calling update_status_and_buttons\n"));
+	    g_print(" new state: starting\n");
+            g_print("handle_button_press : calling update_status_and_buttons\n");
 #endif
             update_status_and_buttons(self);
 	    /* open a new log file */
 	    logfile_start(self);
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- calling location_gpsd_control_start\n"), __func__);
+        g_fprintf(self->logfile, "%s -- calling location_gpsd_control_start\n", __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -710,8 +710,8 @@ handle_button_press (GtkWidget *button,
 	else if (self->app_state == APP_STATE_RECORDING) {
             self->app_state = APP_STATE_PAUSED;
 #ifndef __arm__
-	    g_print(_(" new state: paused\n"));
-            g_print(_("handle_button_press : calling update_status_and_buttons\n"));
+	    g_print(" new state: paused\n");
+            g_print("handle_button_press : calling update_status_and_buttons\n");
 #endif
             update_status_and_buttons(self);
             location_gpsd_control_stop(self->control);
@@ -719,8 +719,8 @@ handle_button_press (GtkWidget *button,
 	else if (self->app_state == APP_STATE_PAUSED) {
             self->app_state = APP_STATE_STARTING;
 #ifndef __arm__
-	    g_print(_(" new state: starting, after pause\n"));
-            g_print(_("handle_button_press : calling update_status_and_buttons\n"));
+	    g_print(" new state: starting, after pause\n");
+            g_print("handle_button_press : calling update_status_and_buttons\n");
 #endif
             update_status_and_buttons(self);
 	    /* close tarck segment and start a new one,
@@ -743,8 +743,8 @@ handle_button_press (GtkWidget *button,
 	}
 	self->app_state = APP_STATE_STOPPING;
 #ifndef __arm__
-	g_print(_(" new state: stoping\n"));
-        g_print(_("handle_button_press : calling update_status_and_buttons\n"));
+	g_print(" new state: stoping\n");
+        g_print("handle_button_press : calling update_status_and_buttons\n");
 #endif
         update_status_and_buttons(self);
         location_gpsd_control_stop(self->control);
@@ -753,7 +753,7 @@ handle_button_press (GtkWidget *button,
     }
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- leave (new state: %d)\n"), __func__, self->app_state);
+        g_fprintf(self->logfile, "%s -- leave (new state: %d)\n", __func__, self->app_state);
 	fflush(self->logfile);
     }
 #endif
@@ -767,13 +767,13 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
 
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- enter "), __func__);
+        g_fprintf(self->logfile, "%s -- enter ", __func__);
         if (widget == GTK_WIDGET(self->background)) {
-	    g_fprintf(self->logfile, _(" widget: background\n"));
+	    g_fprintf(self->logfile, " widget: background\n");
 	} else if (widget == GTK_WIDGET(self->button_rec)) {
-	    g_fprintf(self->logfile, _(" widget: button_rec\n"));
+	    g_fprintf(self->logfile, " widget: button_rec\n");
 	} else if (widget == GTK_WIDGET(self->button_stop)) {
-	    g_fprintf(self->logfile, _(" widget: button_stop\n"));
+	    g_fprintf(self->logfile, " widget: button_stop\n");
 	}
 	fflush(self->logfile);
     }
@@ -793,7 +793,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
             self->rec_button_enabled) {
 #ifdef DEBUG
                 if (self->logfile) {
-                    g_fprintf(self->logfile, _("  calling handle_button_press on background for button_rec\n"));
+                    g_fprintf(self->logfile, "  calling handle_button_press on background for button_rec\n");
 	            fflush(self->logfile);
 		}
 #endif
@@ -807,7 +807,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
             self->stop_button_enabled) {
 #ifdef DEBUG
                 if (self->logfile) {
-                    g_fprintf(self->logfile, _("  calling handle_button_press on background for button_stop\n"));
+                    g_fprintf(self->logfile, "  calling handle_button_press on background for button_stop\n");
 	            fflush(self->logfile);
 		}
 #endif
@@ -817,7 +817,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
 		    self->rec_button_enabled) {
 #ifdef DEBUG
         if (self->logfile) {
-            g_fprintf(self->logfile, _("  calling handle_button_press on button_rec for button_rec\n"));
+            g_fprintf(self->logfile, "  calling handle_button_press on button_rec for button_rec\n");
 	    fflush(self->logfile);
 	}
 #endif
@@ -826,7 +826,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
 		    self->stop_button_enabled) {
 #ifdef DEBUG
         if (self->logfile) {
-             g_fprintf(self->logfile, _("  calling handle_button_press on button_stop for button_stop\n"));
+             g_fprintf(self->logfile, "  calling handle_button_press on button_stop for button_stop\n");
 	     fflush(self->logfile);
 	}
 #endif
@@ -835,7 +835,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
     
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- leave\n"), __func__);
+        g_fprintf(self->logfile, "%s -- leave\n", __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -850,13 +850,13 @@ on_button_press(GtkWidget* widget, GdkEventButton *button_event, gpointer data)
 
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- enter "), __func__);
+        g_fprintf(self->logfile, "%s -- enter ", __func__);
         if (widget == GTK_WIDGET(self->background)) {
-	    g_fprintf(self->logfile, _(" widget: background\n"));
+	    g_fprintf(self->logfile, " widget: background\n");
 	} else if (widget == GTK_WIDGET(self->button_rec)) {
-	    g_fprintf(self->logfile, _(" widget: button_rec\n"));
+	    g_fprintf(self->logfile, " widget: button_rec\n");
 	} else if (widget == GTK_WIDGET(self->button_stop)) {
-	    g_fprintf(self->logfile, _(" widget: button_stop\n"));
+	    g_fprintf(self->logfile, " widget: button_stop\n");
 	}
 	fflush(self->logfile);
     }
@@ -895,7 +895,7 @@ on_button_press(GtkWidget* widget, GdkEventButton *button_event, gpointer data)
 
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- leave\n"), __func__);
+        g_fprintf(self->logfile, "%s -- leave\n", __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -911,7 +911,7 @@ on_error(LocationGPSDControl *control, gpointer data)
 #endif
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- enter\n"), __func__);
+        g_fprintf(self->logfile, "%s -- enter\n", __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -922,7 +922,7 @@ on_error(LocationGPSDControl *control, gpointer data)
 	self->app_state = APP_STATE_IDLE;
 	location_gpsd_control_stop(self->control);
 #ifndef __arm__
-        g_print(_("on_error : calling update_status_and_buttons\n"));
+        g_print("on_error : calling update_status_and_buttons\n");
 #endif
 	update_status_and_buttons(self);
 	logfile_close(self);
@@ -938,7 +938,7 @@ on_start(LocationGPSDControl *control, gpointer data)
 #ifdef DEBUG
     GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (data);
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- was here\n"), __func__);
+        g_fprintf(self->logfile, "%s -- was here\n", __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -961,7 +961,7 @@ on_stop(LocationGPSDControl *control, gpointer data)
 #endif
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, _("%s -- enter\n"), __func__);
+        g_fprintf(self->logfile, "%s -- enter\n", __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -978,11 +978,11 @@ on_stop(LocationGPSDControl *control, gpointer data)
 	    }
 	    self->app_state = APP_STATE_IDLE;
 #ifndef __arm__
-            g_print(_("on_stop : calling update_status_and_buttons\n"));
+            g_print("on_stop : calling update_status_and_buttons\n");
 #endif
 #ifdef DEBUG
             if (self->logfile) {
-                g_fprintf(self->logfile, _("%s -- going to IDLE, calling update_status_and_buttons\n"), __func__);
+                g_fprintf(self->logfile, "%s -- going to IDLE, calling update_status_and_buttons\n", __func__);
 	        fflush(self->logfile);
             }
 #endif
@@ -1020,7 +1020,7 @@ on_changed(LocationGPSDevice *device, gpointer data)
                   
                             self->app_state = APP_STATE_RECORDING;
 #ifndef __arm__
-                            g_print(_("on_change : calling update_status_and_buttons\n"));
+                            g_print("on_change : calling update_status_and_buttons\n");
 #endif
                             update_status_and_buttons(self);
 	                    self->points_recorded_in_current_segment = 0;
@@ -1076,8 +1076,15 @@ on_changed(LocationGPSDevice *device, gpointer data)
 					tp->tm_hour,
 					tp->tm_min,
 					tp->tm_sec);
+			if (device->fix->mode == LOCATION_GPS_DEVICE_MODE_2D)
+				g_fprintf(self->file, "  <fix>2d</fix>\n");
+			else if (device->fix->mode == LOCATION_GPS_DEVICE_MODE_3D)
+				g_fprintf(self->file, "  <fix>3d</fix>\n");
 			g_fprintf(self->file, "  <sat>%d</sat>\n",
 					device->satellites_in_use);
+			/* eph is in cm */
+			g_fprintf(self->file,  "  <hdop>%.1f</hdop>\n", device->fix->eph / 100.0);
+			g_fprintf(self->file,  "  <vdop>%.1f</vdop>\n", device->fix->epv);
 			g_fprintf(self->file, "</trkpt>\n");
 			self->points_recorded_in_current_segment += 1;
 		} /* STARING & RECORDING & has coordinates */
@@ -1313,7 +1320,7 @@ void hw_event_handler(osso_hw_state_t *state, gpointer data)
         should_stop_recording = TRUE;
 #ifdef DEBUG
         if (self->logfile) {
-            g_fprintf(self->logfile, _("  Shutdown event!\n"));
+            g_fprintf(self->logfile, "  Shutdown event!\n");
             fflush(self->logfile);
         }
 #endif
@@ -1325,7 +1332,7 @@ void hw_event_handler(osso_hw_state_t *state, gpointer data)
         should_stop_recording = TRUE;
 #ifdef DEBUG
         if (self->logfile) {
-            g_fprintf(self->logfile, _("  Must save unsaved data event!\n"));
+            g_fprintf(self->logfile, "  Must save unsaved data event!\n");
             fflush(self->logfile);
         }
 #endif
@@ -1447,7 +1454,7 @@ gps_data_logger_widget_init (GpsDataLoggerWidget * self)
     gtk_box_pack_start (GTK_BOX (vbox), hbox_buttons, FALSE, FALSE, 0);
      
 #ifndef __arm__
-    g_print(_("init : calling update_status_and_buttons\n"));
+    g_print("init : calling update_status_and_buttons\n");
 #endif
     update_status_and_buttons(self);
 
@@ -1526,7 +1533,7 @@ gps_data_logger_widget_init (GpsDataLoggerWidget * self)
         if (result != OSSO_OK)
         {
 #ifndef __arm__
-            g_print(_("Error setting HW state callback (%d)\n"), result);
+            g_print("Error setting HW state callback (%d)\n", result);
 #endif
         }
     }
